#ifndef LIBKYPROCESSSEC_H
#define LIBKYPROCESSSEC_H

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 设置进程不可被杀死
 * @param filepath[in] 文件路径
 * @return int
 *       0： 成功
 *       1：包含该path的节点已经存在
 *       2：该path在黑名单中
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数绝对路径异常
 *      -4：参数绝对路径不存在
 *      -5：获取指定路径path在xml文件中的节点数据失败
 *      -6：内核通讯失败
 */
extern int kdk_process_set_anti_killed(const char *filepath);

/**
 * @brief 取消设置进程不可被杀死
 * @param filepath[in] 文件路径
 * @return int
 *       0： 成功
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数绝对路径异常
 *      -4：参数绝对路径不存在
 *      -5：获取指定路径path在xml文件中的节点数据失败
 *      -6：内核通讯失败
 *      -7：移除程序进程保护失败
 */
extern int kdk_process_cancel_anti_killed(const char *filepath);

/**
 * @brief 读取所有节点信息
 * 
 * @param count 节点数量
 * @return char** 
 *      NULL：失败或记录不存在
 *      其他：成功，配置信息数组
 */
extern char **kdk_process_get_anti_killed(int *count);

/**
 * @brief 设置进程可执行
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_set_executable(const char *filepath);

/**
 * @brief 取消设置进程可执行
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_cancel_executable(const char *filepath);

/**
 * @brief 设置内核模块不可卸载
 * @param filename[in] 文件名
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_kmod_set_anti_unloaded(const char *koname);

/**
 * @brief 取消设置内核模块不可卸载
 * @param filename[in] 文件名
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_kmod_cancel_anti_unloaded(const char *koname);

/**
 * @brief 设置内核模块不可卸载
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 *       0： 成功
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数路径不存在
 *      -4：添加程序至内核模块防卸载失败
 
 */
extern int kdk_kmod_set_anti_unloaded_by_path(const char *filepath);

/**
 * @brief 取消设置内核模块不可卸载
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 *       0： 成功
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数路径不存在
 *      -4：移除程序至内核模块防卸载失败
 */
extern int kdk_kmod_cancel_anti_unloaded_by_path(const char *filepath);

/**
 * @brief 读取所有节点信息
 * 
 * @param count 节点数量
 * @return char** 
 *      NULL：失败或记录不存在
 *      其他：成功，配置信息数组
 */
extern char **kdk_kmod_get_anti_unloaded(int *count);

/**
 * @brief 设置进程可以联网
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_enable_networking(const char *filepath);

/**
 * @brief 设置进程不可联网
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_disable_networking(const char *filepath);

/**
 * @brief 设置关键进程
 * @param filepath[in] 文件路径
 * @return int
 *       0： 成功
 *       1：包含该path的节点已经存在
 *       2：该path在黑名单中
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数绝对路径异常
 *      -4：参数绝对路径不存在
 *      -5：获取指定路径path在xml文件中的节点数据失败
 *      -6：内核通讯失败
 */
extern int kdk_process_set_key_process(const char *filepath);

/**
 * @brief 取消关键进程
 * @param filepath[in] 文件路径
 * @return int
 *       0： 成功
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数绝对路径异常
 *      -4：参数绝对路径不存在
 *      -5：获取指定路径path在xml文件中的节点数据失败
 *      -6：内核通讯失败
 *      -7：移除程序进程保护失败
 */
extern int kdk_process_cancel_key_process(const char *filepath);

/**
 * @brief 获取关键进程列表
 *
 * @param count 关键进程数量
 * @return char**
 *      NULL：失败或记录不存在
 *      其他：成功，关键进程数组
 */
extern char **kdk_process_get_key_process(int *count);

#ifdef __cplusplus
}
#endif

#endif//LIBKYPROCESSSEC_H
